// This file was automatically generated.  Do not modify.

'use strict';

goog.provide('Blockly.Msg.zh.hans');

goog.require('Blockly.Msg');

Blockly.Msg.ADD_COMMENT = "添加注释";
Blockly.Msg.AUTH = "请授权这个应用程序以保存您的作品并共享。";
Blockly.Msg.CHANGE_VALUE_TITLE = "更改值：";
Blockly.Msg.CHAT = "通过在此框输入与您的合作者沟通！";
Blockly.Msg.COLLAPSE_ALL = "折叠块";
Blockly.Msg.COLLAPSE_BLOCK = "折叠块";
Blockly.Msg.COLOUR_BLEND_COLOUR1 = "颜色1";
Blockly.Msg.COLOUR_BLEND_COLOUR2 = "颜色2";
Blockly.Msg.COLOUR_BLEND_HELPURL = "http://meyerweb.com/eric/tools/color-blend/";  // untranslated
Blockly.Msg.COLOUR_BLEND_RATIO = "比例";
Blockly.Msg.COLOUR_BLEND_TITLE = "混合";
Blockly.Msg.COLOUR_BLEND_TOOLTIP = "用一个给定的比率(0.0-1.0)混合两种颜色。";
Blockly.Msg.COLOUR_PICKER_HELPURL = "https://zh.wikipedia.org/wiki/颜色";
Blockly.Msg.COLOUR_PICKER_TOOLTIP = "从调色板中选择一种颜色。";
Blockly.Msg.COLOUR_RANDOM_HELPURL = "http://randomcolour.com";  // untranslated
Blockly.Msg.COLOUR_RANDOM_TITLE = "随机颜色";
Blockly.Msg.COLOUR_RANDOM_TOOLTIP = "随机选择一种颜色。";
Blockly.Msg.COLOUR_RGB_BLUE = "蓝色";
Blockly.Msg.COLOUR_RGB_GREEN = "绿色";
Blockly.Msg.COLOUR_RGB_HELPURL = "http://www.december.com/html/spec/colorper.html";  // untranslated
Blockly.Msg.COLOUR_RGB_RED = "红色";
Blockly.Msg.COLOUR_RGB_TITLE = "颜色";
Blockly.Msg.COLOUR_RGB_TOOLTIP = "通过指定红色、绿色和蓝色的量创建一种颜色。所有的值必须介于0和100之间。";
Blockly.Msg.CONTROLS_FLOW_STATEMENTS_HELPURL = "https://github.com/google/blockly/wiki/Loops#loop-termination-blocks";  // untranslated
Blockly.Msg.CONTROLS_FLOW_STATEMENTS_OPERATOR_BREAK = "中断循环";
Blockly.Msg.CONTROLS_FLOW_STATEMENTS_OPERATOR_CONTINUE = "继续下一次循环";
Blockly.Msg.CONTROLS_FLOW_STATEMENTS_TOOLTIP_BREAK = "中断包含它的循环。";
Blockly.Msg.CONTROLS_FLOW_STATEMENTS_TOOLTIP_CONTINUE = "跳过这个循环的剩余部分，并继续下一次迭代。";
Blockly.Msg.CONTROLS_FLOW_STATEMENTS_WARNING = "警告：此块仅可用于在一个循环内。";
Blockly.Msg.CONTROLS_FOREACH_HELPURL = "https://github.com/google/blockly/wiki/Loops#for-each";  // untranslated
Blockly.Msg.CONTROLS_FOREACH_TITLE = "为每个项目 %1 在列表中 %2";
Blockly.Msg.CONTROLS_FOREACH_TOOLTIP = "遍历每个列表中的项目，将变量“%1”设定到该项中，然后执行某些语句。";
Blockly.Msg.CONTROLS_FOR_HELPURL = "https://github.com/google/blockly/wiki/Loops#count-with";  // untranslated
Blockly.Msg.CONTROLS_FOR_TITLE = "使用 %1 从范围 %2 到 %3 每隔 %4";
Blockly.Msg.CONTROLS_FOR_TOOLTIP = "从起始数到结尾数中取出变量“%1”的值，按指定的时间间隔，执行指定的块。";
Blockly.Msg.CONTROLS_IF_ELSEIF_TOOLTIP = "在if语句块中增加一个条件。";
Blockly.Msg.CONTROLS_IF_ELSE_TOOLTIP = "添加一个最终的，包括所有情况的节到if块中。";
Blockly.Msg.CONTROLS_IF_HELPURL = "https://github.com/google/blockly/wiki/IfElse";  // untranslated
Blockly.Msg.CONTROLS_IF_IF_TOOLTIP = "增加、删除或重新排列各节来重新配置“if”块。";
Blockly.Msg.CONTROLS_IF_MSG_ELSE = "否则";
Blockly.Msg.CONTROLS_IF_MSG_ELSEIF = "否则如果";
Blockly.Msg.CONTROLS_IF_MSG_IF = "如果";
Blockly.Msg.CONTROLS_IF_TOOLTIP_1 = "如果值为真，执行一些语句。";
Blockly.Msg.CONTROLS_IF_TOOLTIP_2 = "如果值为真，则执行语句的第一块；否则，则执行语句的第二块。";
Blockly.Msg.CONTROLS_IF_TOOLTIP_3 = "如果第一个值为真，则执行语句的第一个块；否则，如果第二个值为真，则执行语句的第二块。";
Blockly.Msg.CONTROLS_IF_TOOLTIP_4 = "如果第一个值为真，则执行语句的第一块；否则，如果第二个值为真，则执行语句的第二块；如果没有值为真，则执行语句的最后一块。";
Blockly.Msg.CONTROLS_REPEAT_HELPURL = "https://zh.wikipedia.org/wiki/For循环";
Blockly.Msg.CONTROLS_REPEAT_INPUT_DO = "执行";
Blockly.Msg.CONTROLS_REPEAT_TITLE = "重复 %1 次";
Blockly.Msg.CONTROLS_REPEAT_TOOLTIP = "多次执行一些语句。";
Blockly.Msg.CONTROLS_WHILEUNTIL_HELPURL = "https://github.com/google/blockly/wiki/Loops#repeat";  // untranslated
Blockly.Msg.CONTROLS_WHILEUNTIL_OPERATOR_UNTIL = "重复直到";
Blockly.Msg.CONTROLS_WHILEUNTIL_OPERATOR_WHILE = "重复当";
Blockly.Msg.CONTROLS_WHILEUNTIL_TOOLTIP_UNTIL = "只要值为假，执行一些语句。";
Blockly.Msg.CONTROLS_WHILEUNTIL_TOOLTIP_WHILE = "只要值为真，执行一些语句。";
Blockly.Msg.DELETE_BLOCK = "删除块";
Blockly.Msg.DELETE_X_BLOCKS = "删除 %1 块";
Blockly.Msg.DISABLE_BLOCK = "禁用块";
Blockly.Msg.DUPLICATE_BLOCK = "复制";
Blockly.Msg.ENABLE_BLOCK = "启用块";
Blockly.Msg.EXPAND_ALL = "展开块";
Blockly.Msg.EXPAND_BLOCK = "展开块";
Blockly.Msg.EXTERNAL_INPUTS = "外部输入";
Blockly.Msg.HELP = "帮助";
Blockly.Msg.INLINE_INPUTS = "单行输入";
Blockly.Msg.LISTS_CREATE_EMPTY_HELPURL = "https://github.com/google/blockly/wiki/Lists#create-empty-list";
Blockly.Msg.LISTS_CREATE_EMPTY_TITLE = "创建空列表";
Blockly.Msg.LISTS_CREATE_EMPTY_TOOLTIP = "返回一个列表，长度为 0，不包含任何数据记录";
Blockly.Msg.LISTS_CREATE_WITH_CONTAINER_TITLE_ADD = "列表";
Blockly.Msg.LISTS_CREATE_WITH_CONTAINER_TOOLTIP = "增加、删除或重新排列各部分以此重新配置这个列表块。";
Blockly.Msg.LISTS_CREATE_WITH_HELPURL = "https://github.com/google/blockly/wiki/Lists#create-list-with";
Blockly.Msg.LISTS_CREATE_WITH_INPUT_WITH = "建立字串使用";
Blockly.Msg.LISTS_CREATE_WITH_ITEM_TOOLTIP = "将一个项添加到列表中。";
Blockly.Msg.LISTS_CREATE_WITH_TOOLTIP = "建立一个具有任意数量项目的列表。";
Blockly.Msg.LISTS_GET_INDEX_FIRST = "第一";
Blockly.Msg.LISTS_GET_INDEX_FROM_END = "倒数第#";
Blockly.Msg.LISTS_GET_INDEX_FROM_START = "#";
Blockly.Msg.LISTS_GET_INDEX_GET = "获得";
Blockly.Msg.LISTS_GET_INDEX_GET_REMOVE = "取出并移除";
Blockly.Msg.LISTS_GET_INDEX_LAST = "最后";
Blockly.Msg.LISTS_GET_INDEX_RANDOM = "随机";
Blockly.Msg.LISTS_GET_INDEX_REMOVE = "移除";
Blockly.Msg.LISTS_GET_INDEX_TAIL = "空白";
Blockly.Msg.LISTS_GET_INDEX_TOOLTIP_GET_FIRST = "返回列表中的第一个项目。";
Blockly.Msg.LISTS_GET_INDEX_TOOLTIP_GET_FROM_END = "返回在列表中的指定位置的项。#1是最后一项。";
Blockly.Msg.LISTS_GET_INDEX_TOOLTIP_GET_FROM_START = "返回在列表中的指定位置的项。#1是第一个项目。";
Blockly.Msg.LISTS_GET_INDEX_TOOLTIP_GET_LAST = "返回列表中的最后一项。";
Blockly.Msg.LISTS_GET_INDEX_TOOLTIP_GET_RANDOM = "随机返回列表中的一个项目。";
Blockly.Msg.LISTS_GET_INDEX_TOOLTIP_GET_REMOVE_FIRST = "移除并返回列表中的第一个项目。";
Blockly.Msg.LISTS_GET_INDEX_TOOLTIP_GET_REMOVE_FROM_END = "移除并返回列表中的指定位置的项。#1 是最后一项。";
Blockly.Msg.LISTS_GET_INDEX_TOOLTIP_GET_REMOVE_FROM_START = "移除并返回列表中的指定位置的项。#1 是第一项。";
Blockly.Msg.LISTS_GET_INDEX_TOOLTIP_GET_REMOVE_LAST = "移除并返回列表中的最后一个项目。";
Blockly.Msg.LISTS_GET_INDEX_TOOLTIP_GET_REMOVE_RANDOM = "移除并返回列表中的一个随机项目中。";
Blockly.Msg.LISTS_GET_INDEX_TOOLTIP_REMOVE_FIRST = "移除列表中的第一项";
Blockly.Msg.LISTS_GET_INDEX_TOOLTIP_REMOVE_FROM_END = "删除在列表中的指定位置的项。#1是最后一项。";
Blockly.Msg.LISTS_GET_INDEX_TOOLTIP_REMOVE_FROM_START = "移除在列表中的指定位置的项。#1 是第一项。";
Blockly.Msg.LISTS_GET_INDEX_TOOLTIP_REMOVE_LAST = "移除列表中的最后一项";
Blockly.Msg.LISTS_GET_INDEX_TOOLTIP_REMOVE_RANDOM = "删除列表中的一个随机的项。";
Blockly.Msg.LISTS_GET_SUBLIST_END_FROM_END = "到倒数第#";
Blockly.Msg.LISTS_GET_SUBLIST_END_FROM_START = "到#";
Blockly.Msg.LISTS_GET_SUBLIST_END_LAST = "到最后";
Blockly.Msg.LISTS_GET_SUBLIST_HELPURL = "https://github.com/google/blockly/wiki/Lists#getting-a-sublist";  // untranslated
Blockly.Msg.LISTS_GET_SUBLIST_START_FIRST = "从头获得子列表";
Blockly.Msg.LISTS_GET_SUBLIST_START_FROM_END = "从倒数#取得子列表";
Blockly.Msg.LISTS_GET_SUBLIST_START_FROM_START = "从#取得子列表";
Blockly.Msg.LISTS_GET_SUBLIST_TAIL = "空白";
Blockly.Msg.LISTS_GET_SUBLIST_TOOLTIP = "复制列表中指定的部分。";
Blockly.Msg.LISTS_INDEX_OF_FIRST = "找出第一个项出现";
Blockly.Msg.LISTS_INDEX_OF_HELPURL = "https://github.com/google/blockly/wiki/Lists#getting-items-from-a-list";  // untranslated
Blockly.Msg.LISTS_INDEX_OF_LAST = "找出最后一个项出现";
Blockly.Msg.LISTS_INDEX_OF_TOOLTIP = "返回在列表中的第一/最后一个匹配项的索引值。如果未找到则返回 0。";
Blockly.Msg.LISTS_INLIST = "在列表中";
Blockly.Msg.LISTS_ISEMPTY_HELPURL = "https://github.com/google/blockly/wiki/Lists#is-empty";  // untranslated
Blockly.Msg.LISTS_ISEMPTY_TITLE = "%1是空的";
Blockly.Msg.LISTS_ISEMPTY_TOOLTIP = "如果改列表为空，则返回真。";
Blockly.Msg.LISTS_LENGTH_HELPURL = "https://github.com/google/blockly/wiki/Lists#length-of";  // untranslated
Blockly.Msg.LISTS_LENGTH_TITLE = "%1的长度";
Blockly.Msg.LISTS_LENGTH_TOOLTIP = "返回列表的长度。";
Blockly.Msg.LISTS_REPEAT_HELPURL = "https://github.com/google/blockly/wiki/Lists#create-list-with";  // untranslated
Blockly.Msg.LISTS_REPEAT_TITLE = "建立列表使用项 %1 重复 %2 次";
Blockly.Msg.LISTS_REPEAT_TOOLTIP = "建立包含指定重复次数的值的列表。";
Blockly.Msg.LISTS_SET_INDEX_HELPURL = "https://github.com/google/blockly/wiki/Lists#in-list--set";  // untranslated
Blockly.Msg.LISTS_SET_INDEX_INPUT_TO = "为";
Blockly.Msg.LISTS_SET_INDEX_INSERT = "插入在";
Blockly.Msg.LISTS_SET_INDEX_SET = "设置";
Blockly.Msg.LISTS_SET_INDEX_TOOLTIP_INSERT_FIRST = "在列表的起始处添加该项。";
Blockly.Msg.LISTS_SET_INDEX_TOOLTIP_INSERT_FROM_END = "插入在列表中的指定位置的项。#1是最后一项。";
Blockly.Msg.LISTS_SET_INDEX_TOOLTIP_INSERT_FROM_START = "插入在列表中指定位置的项。#1是第一项。";
Blockly.Msg.LISTS_SET_INDEX_TOOLTIP_INSERT_LAST = "将该项追加到列表的末尾。";
Blockly.Msg.LISTS_SET_INDEX_TOOLTIP_INSERT_RANDOM = "在列表中随机插入项。";
Blockly.Msg.LISTS_SET_INDEX_TOOLTIP_SET_FIRST = "设置列表中的第一个项目。";
Blockly.Msg.LISTS_SET_INDEX_TOOLTIP_SET_FROM_END = "设置在列表中指定位置的项。#1是最后一项。";
Blockly.Msg.LISTS_SET_INDEX_TOOLTIP_SET_FROM_START = "设置在列表中指定位置的项。#1是第一项。";
Blockly.Msg.LISTS_SET_INDEX_TOOLTIP_SET_LAST = "设置列表中的最后一项。";
Blockly.Msg.LISTS_SET_INDEX_TOOLTIP_SET_RANDOM = "设置列表中一个随机的项目。";
Blockly.Msg.LISTS_SPLIT_HELPURL = "https://github.com/google/blockly/wiki/Lists#splitting-strings-and-joining-lists";
Blockly.Msg.LISTS_SPLIT_LIST_FROM_TEXT = "从文本制作列表";
Blockly.Msg.LISTS_SPLIT_TEXT_FROM_LIST = "从列表拆出文本";
Blockly.Msg.LISTS_SPLIT_TOOLTIP_JOIN = "加入文本列表至一个文本，由分隔符分隔。";
Blockly.Msg.LISTS_SPLIT_TOOLTIP_SPLIT = "拆分文本到文本列表，按每个分隔符拆分。";
Blockly.Msg.LISTS_SPLIT_WITH_DELIMITER = "用分隔符";
Blockly.Msg.LOGIC_BOOLEAN_FALSE = "错";
Blockly.Msg.LOGIC_BOOLEAN_HELPURL = "https://github.com/google/blockly/wiki/Logic#values";  // untranslated
Blockly.Msg.LOGIC_BOOLEAN_TOOLTIP = "同时返回真或假。";
Blockly.Msg.LOGIC_BOOLEAN_TRUE = "真";
Blockly.Msg.LOGIC_COMPARE_HELPURL = "https://zh.wikipedia.org/wiki/不等";
Blockly.Msg.LOGIC_COMPARE_TOOLTIP_EQ = "如果两个输入结果相等，则返回真。";
Blockly.Msg.LOGIC_COMPARE_TOOLTIP_GT = "如果第一个输入结果比第二个大，则返回真。";
Blockly.Msg.LOGIC_COMPARE_TOOLTIP_GTE = "如果第一个输入结果大于或等于第二个输入结果，则返回真。";
Blockly.Msg.LOGIC_COMPARE_TOOLTIP_LT = "如果第一个输入结果比第二个小，则返回真。";
Blockly.Msg.LOGIC_COMPARE_TOOLTIP_LTE = "如果第一个输入结果小于或等于第二个输入结果，则返回真。";
Blockly.Msg.LOGIC_COMPARE_TOOLTIP_NEQ = "如果两个输入结果不相等，则返回真。";
Blockly.Msg.LOGIC_NEGATE_HELPURL = "https://zh.wikipedia.org/wiki/逻辑非";
Blockly.Msg.LOGIC_NEGATE_TITLE = "并非%1";
Blockly.Msg.LOGIC_NEGATE_TOOLTIP = "如果输入结果为假，则返回真；如果输入结果为真，则返回假。";
Blockly.Msg.LOGIC_NULL = "空";
Blockly.Msg.LOGIC_NULL_HELPURL = "https://en.wikipedia.org/wiki/Nullable_type";  // untranslated
Blockly.Msg.LOGIC_NULL_TOOLTIP = "返回空值。";
Blockly.Msg.LOGIC_OPERATION_AND = "和";
Blockly.Msg.LOGIC_OPERATION_HELPURL = "https://github.com/google/blockly/wiki/Logic#logical-operations";  // untranslated
Blockly.Msg.LOGIC_OPERATION_OR = "或";
Blockly.Msg.LOGIC_OPERATION_TOOLTIP_AND = "如果两个输入结果都为真，则返回真。";
Blockly.Msg.LOGIC_OPERATION_TOOLTIP_OR = "如果至少有一个输入结果为真，则返回真。";
Blockly.Msg.LOGIC_TERNARY_CONDITION = "测试";
Blockly.Msg.LOGIC_TERNARY_HELPURL = "https://zh.wikipedia.org/wiki/条件运算符";
Blockly.Msg.LOGIC_TERNARY_IF_FALSE = "如果为假";
Blockly.Msg.LOGIC_TERNARY_IF_TRUE = "如果为真";
Blockly.Msg.LOGIC_TERNARY_TOOLTIP = "检查“test”中的条件。如果条件为真，则返回“if true”的值，否则，则返回“if false”的值。";
Blockly.Msg.MATH_ADDITION_SYMBOL = "+";  // untranslated
Blockly.Msg.MATH_ARITHMETIC_HELPURL = "https://zh.wikipedia.org/wiki/算术";
Blockly.Msg.MATH_ARITHMETIC_TOOLTIP_ADD = "返回两个数字的和。";
Blockly.Msg.MATH_ARITHMETIC_TOOLTIP_DIVIDE = "返回两个数字的商。";
Blockly.Msg.MATH_ARITHMETIC_TOOLTIP_MINUS = "返回两个数字的区别。";
Blockly.Msg.MATH_ARITHMETIC_TOOLTIP_MULTIPLY = "返回两个数字的乘积。";
Blockly.Msg.MATH_ARITHMETIC_TOOLTIP_POWER = "返回第一个数的第二个数次幂。";
Blockly.Msg.MATH_CHANGE_HELPURL = "https://zh.wikipedia.org/wiki/%E5%8A%A0%E6%B3%95";
Blockly.Msg.MATH_CHANGE_TITLE = "更改 %1 由 %2";
Blockly.Msg.MATH_CHANGE_TOOLTIP = "将一个数添加到变量“%1”。";
Blockly.Msg.MATH_CONSTANT_HELPURL = "https://zh.wikipedia.org/wiki/数学常数";
Blockly.Msg.MATH_CONSTANT_TOOLTIP = "返回一个常见常量：π (3.141......)，e (2.718...)、φ (1.618...)、 sqrt(2) (1.414......)、sqrt(½) (0.707......)或 ∞（无穷大）。";
Blockly.Msg.MATH_CONSTRAIN_HELPURL = "https://en.wikipedia.org/wiki/Clamping_%28graphics%29";  // untranslated
Blockly.Msg.MATH_CONSTRAIN_TITLE = "限制数字 %1 介于 (低) %2 到 (高) %3";
Blockly.Msg.MATH_CONSTRAIN_TOOLTIP = "限制数字介于两个指定的数字之间";
Blockly.Msg.MATH_DIVISION_SYMBOL = "÷";  // untranslated
Blockly.Msg.MATH_IS_DIVISIBLE_BY = "可被整除";
Blockly.Msg.MATH_IS_EVEN = "是偶数";
Blockly.Msg.MATH_IS_NEGATIVE = "为负";
Blockly.Msg.MATH_IS_ODD = "是奇数";
Blockly.Msg.MATH_IS_POSITIVE = "是正值";
Blockly.Msg.MATH_IS_PRIME = "是质数";
Blockly.Msg.MATH_IS_TOOLTIP = "如果数字是偶数、奇数、非负整数、正数、负数或如果它可被某数字整除，则返回真或假。";
Blockly.Msg.MATH_IS_WHOLE = "为整数";
Blockly.Msg.MATH_MODULO_HELPURL = "https://zh.wikipedia.org/wiki/模除";
Blockly.Msg.MATH_MODULO_TITLE = "取余数自 %1 ÷ %2";
Blockly.Msg.MATH_MODULO_TOOLTIP = "返回这两个数字相除后的余数。";
Blockly.Msg.MATH_MULTIPLICATION_SYMBOL = "×";  // untranslated
Blockly.Msg.MATH_NUMBER_HELPURL = "https://zh.wikipedia.org/wiki/数";
Blockly.Msg.MATH_NUMBER_TOOLTIP = "一个数字。";
Blockly.Msg.MATH_ONLIST_HELPURL = "";  // untranslated
Blockly.Msg.MATH_ONLIST_OPERATOR_AVERAGE = "列表中的平均数";
Blockly.Msg.MATH_ONLIST_OPERATOR_MAX = "列表中的最大值";
Blockly.Msg.MATH_ONLIST_OPERATOR_MEDIAN = "列表中位数";
Blockly.Msg.MATH_ONLIST_OPERATOR_MIN = "列表中的最小值";
Blockly.Msg.MATH_ONLIST_OPERATOR_MODE = "列表模式";
Blockly.Msg.MATH_ONLIST_OPERATOR_RANDOM = "列表的随机项";
Blockly.Msg.MATH_ONLIST_OPERATOR_STD_DEV = "列表中的标准差";
Blockly.Msg.MATH_ONLIST_OPERATOR_SUM = "列表中的数的总和";
Blockly.Msg.MATH_ONLIST_TOOLTIP_AVERAGE = "返回列表中的数值的平均值。";
Blockly.Msg.MATH_ONLIST_TOOLTIP_MAX = "返回列表中最大数。";
Blockly.Msg.MATH_ONLIST_TOOLTIP_MEDIAN = "返回列表中的中位数。";
Blockly.Msg.MATH_ONLIST_TOOLTIP_MIN = "返回列表中最小数。";
Blockly.Msg.MATH_ONLIST_TOOLTIP_MODE = "返回列表中的最常见的项的列表。";
Blockly.Msg.MATH_ONLIST_TOOLTIP_RANDOM = "从列表中返回一个随机的元素。";
Blockly.Msg.MATH_ONLIST_TOOLTIP_STD_DEV = "返回列表的标准偏差。";
Blockly.Msg.MATH_ONLIST_TOOLTIP_SUM = "返回列表中的所有数字的和。";
Blockly.Msg.MATH_POWER_SYMBOL = "^";  // untranslated
Blockly.Msg.MATH_RANDOM_FLOAT_HELPURL = "https://zh.wikipedia.org/wiki/随机数生成器";
Blockly.Msg.MATH_RANDOM_FLOAT_TITLE_RANDOM = "随机分数";
Blockly.Msg.MATH_RANDOM_FLOAT_TOOLTIP = "返回介于（包含）0.0到1.0之间的随机数。";
Blockly.Msg.MATH_RANDOM_INT_HELPURL = "https://zh.wikipedia.org/wiki/随机数生成器";
Blockly.Msg.MATH_RANDOM_INT_TITLE = "从 %1 到 %2 之间的随机整数";
Blockly.Msg.MATH_RANDOM_INT_TOOLTIP = "返回两个指定的范围（含）之间的随机整数。";
Blockly.Msg.MATH_ROUND_HELPURL = "https://zh.wikipedia.org/wiki/数值修约";
Blockly.Msg.MATH_ROUND_OPERATOR_ROUND = "向下舍入";
Blockly.Msg.MATH_ROUND_OPERATOR_ROUNDDOWN = "向下舍入";
Blockly.Msg.MATH_ROUND_OPERATOR_ROUNDUP = "向上舍入";
Blockly.Msg.MATH_ROUND_TOOLTIP = "数字向上或向下舍入。";
Blockly.Msg.MATH_SINGLE_HELPURL = "https://zh.wikipedia.org/wiki/平方根";
Blockly.Msg.MATH_SINGLE_OP_ABSOLUTE = "绝对";
Blockly.Msg.MATH_SINGLE_OP_ROOT = "平方根";
Blockly.Msg.MATH_SINGLE_TOOLTIP_ABS = "返回一个数的绝对值。";
Blockly.Msg.MATH_SINGLE_TOOLTIP_EXP = "返回数的e次幂。";
Blockly.Msg.MATH_SINGLE_TOOLTIP_LN = "返回一个数的自然对数。";
Blockly.Msg.MATH_SINGLE_TOOLTIP_LOG10 = "返回数字的对数。";
Blockly.Msg.MATH_SINGLE_TOOLTIP_NEG = "返回数的逻辑非。";
Blockly.Msg.MATH_SINGLE_TOOLTIP_POW10 = "返回数的10次幂。";
Blockly.Msg.MATH_SINGLE_TOOLTIP_ROOT = "返回数的平方根。";
Blockly.Msg.MATH_SUBTRACTION_SYMBOL = "-";  // untranslated
Blockly.Msg.MATH_TRIG_ACOS = "acos";  // untranslated
Blockly.Msg.MATH_TRIG_ASIN = "asin";  // untranslated
Blockly.Msg.MATH_TRIG_ATAN = "atan";  // untranslated
Blockly.Msg.MATH_TRIG_COS = "cos";  // untranslated
Blockly.Msg.MATH_TRIG_HELPURL = "https://zh.wikipedia.org/wiki/三角函数";
Blockly.Msg.MATH_TRIG_SIN = "sin";  // untranslated
Blockly.Msg.MATH_TRIG_TAN = "tan";  // untranslated
Blockly.Msg.MATH_TRIG_TOOLTIP_ACOS = "返回一个数的反余弦值。";
Blockly.Msg.MATH_TRIG_TOOLTIP_ASIN = "返回一个数的反正弦值。";
Blockly.Msg.MATH_TRIG_TOOLTIP_ATAN = "返回指定角度的反正切值。";
Blockly.Msg.MATH_TRIG_TOOLTIP_COS = "返回指定角度的余弦值(非弧度）。";
Blockly.Msg.MATH_TRIG_TOOLTIP_SIN = "返回指定角度的正弦值(非弧度）。";
Blockly.Msg.MATH_TRIG_TOOLTIP_TAN = "返回指定角度的正切值(非弧度）。";
Blockly.Msg.ME = "我";
Blockly.Msg.NEW_VARIABLE = "新变量...";
Blockly.Msg.NEW_VARIABLE_TITLE = "新变量的名称：";
Blockly.Msg.ORDINAL_NUMBER_SUFFIX = "空白";
Blockly.Msg.PROCEDURES_ALLOW_STATEMENTS = "允许声明";
Blockly.Msg.PROCEDURES_BEFORE_PARAMS = "与：";
Blockly.Msg.PROCEDURES_CALLNORETURN_CALL = "空白";
Blockly.Msg.PROCEDURES_CALLNORETURN_HELPURL = "https://zh.wikipedia.org/wiki/子程序";
Blockly.Msg.PROCEDURES_CALLNORETURN_TOOLTIP = "运行用户定义的函数“%1”。";
Blockly.Msg.PROCEDURES_CALLRETURN_HELPURL = "https://zh.wikipedia.org/wiki/子程序";
Blockly.Msg.PROCEDURES_CALLRETURN_TOOLTIP = "运行用户定义的函数“%1”，并使用它的输出值。";
Blockly.Msg.PROCEDURES_CALL_BEFORE_PARAMS = "与：";
Blockly.Msg.PROCEDURES_CREATE_DO = "创建“%1”";
Blockly.Msg.PROCEDURES_DEFNORETURN_DO = "空白";
Blockly.Msg.PROCEDURES_DEFNORETURN_HELPURL = "https://zh.wikipedia.org/wiki/子程序";
Blockly.Msg.PROCEDURES_DEFNORETURN_PROCEDURE = "做点什么";
Blockly.Msg.PROCEDURES_DEFNORETURN_TITLE = "至";
Blockly.Msg.PROCEDURES_DEFNORETURN_TOOLTIP = "创建一个不带输出值的函数。";
Blockly.Msg.PROCEDURES_DEFRETURN_HELPURL = "https://zh.wikipedia.org/wiki/子程序";
Blockly.Msg.PROCEDURES_DEFRETURN_RETURN = "返回";
Blockly.Msg.PROCEDURES_DEFRETURN_TOOLTIP = "创建一个有输出值的函数。";
Blockly.Msg.PROCEDURES_DEF_DUPLICATE_WARNING = "警告: 此函数具有重复参数。";
Blockly.Msg.PROCEDURES_HIGHLIGHT_DEF = "突出显示函数定义";
Blockly.Msg.PROCEDURES_IFRETURN_TOOLTIP = "如果值为真，则返回第二个值。";
Blockly.Msg.PROCEDURES_IFRETURN_WARNING = "警告: 仅在定义函数内可使用此块。";
Blockly.Msg.PROCEDURES_MUTATORARG_TITLE = "输入名称：";
Blockly.Msg.PROCEDURES_MUTATORARG_TOOLTIP = "添加函数输入。";
Blockly.Msg.PROCEDURES_MUTATORCONTAINER_TITLE = "输入";
Blockly.Msg.PROCEDURES_MUTATORCONTAINER_TOOLTIP = "添加、删除或重新排此函数的输入。";
Blockly.Msg.REMOVE_COMMENT = "删除注释";
Blockly.Msg.RENAME_VARIABLE = "重命名变量...";
Blockly.Msg.RENAME_VARIABLE_TITLE = "将所有“%1”变量重命名为:";
Blockly.Msg.TEXT_APPEND_APPENDTEXT = "追加文本";
Blockly.Msg.TEXT_APPEND_HELPURL = "https://github.com/google/blockly/wiki/Text#text-modification";  // untranslated
Blockly.Msg.TEXT_APPEND_TO = "在";
Blockly.Msg.TEXT_APPEND_TOOLTIP = "将一些文本追加到变量“%1”。";
Blockly.Msg.TEXT_CHANGECASE_HELPURL = "https://github.com/google/blockly/wiki/Text#adjusting-text-case";  // untranslated
Blockly.Msg.TEXT_CHANGECASE_OPERATOR_LOWERCASE = "为小写";
Blockly.Msg.TEXT_CHANGECASE_OPERATOR_TITLECASE = "为首字母大写";
Blockly.Msg.TEXT_CHANGECASE_OPERATOR_UPPERCASE = "为大写";
Blockly.Msg.TEXT_CHANGECASE_TOOLTIP = "使用不同的大小写复制这段文字。";
Blockly.Msg.TEXT_CHARAT_FIRST = "获得第一个字符";
Blockly.Msg.TEXT_CHARAT_FROM_END = "获得倒数第#个字符";
Blockly.Msg.TEXT_CHARAT_FROM_START = "获得字符#";
Blockly.Msg.TEXT_CHARAT_HELPURL = "https://github.com/google/blockly/wiki/Text#extracting-text";  // untranslated
Blockly.Msg.TEXT_CHARAT_INPUT_INTEXT = "于文本中";
Blockly.Msg.TEXT_CHARAT_LAST = "获得最后一个字符";
Blockly.Msg.TEXT_CHARAT_RANDOM = "获取随机的字母";
Blockly.Msg.TEXT_CHARAT_TAIL = "空白";
Blockly.Msg.TEXT_CHARAT_TOOLTIP = "返回位于指定位置的字母。";
Blockly.Msg.TEXT_CREATE_JOIN_ITEM_TOOLTIP = "将一个项添加到文本中。";
Blockly.Msg.TEXT_CREATE_JOIN_TITLE_JOIN = "加入";
Blockly.Msg.TEXT_CREATE_JOIN_TOOLTIP = "添加、移除或重新排列各节来重新配置这个文本块。";
Blockly.Msg.TEXT_GET_SUBSTRING_END_FROM_END = "到倒数第#个字符";
Blockly.Msg.TEXT_GET_SUBSTRING_END_FROM_START = "到字符#";
Blockly.Msg.TEXT_GET_SUBSTRING_END_LAST = "到最后一个字符";
Blockly.Msg.TEXT_GET_SUBSTRING_HELPURL = "https://github.com/google/blockly/wiki/Text#extracting-a-region-of-text";  // untranslated
Blockly.Msg.TEXT_GET_SUBSTRING_INPUT_IN_TEXT = "自文本";
Blockly.Msg.TEXT_GET_SUBSTRING_START_FIRST = "取得一段字串自第一个字符";
Blockly.Msg.TEXT_GET_SUBSTRING_START_FROM_END = "取得一段字串自#到末尾";
Blockly.Msg.TEXT_GET_SUBSTRING_START_FROM_START = "取得一段字串自#";
Blockly.Msg.TEXT_GET_SUBSTRING_TAIL = "空白";
Blockly.Msg.TEXT_GET_SUBSTRING_TOOLTIP = "返回指定的部分文本。";
Blockly.Msg.TEXT_INDEXOF_HELPURL = "https://github.com/google/blockly/wiki/Text#finding-text";  // untranslated
Blockly.Msg.TEXT_INDEXOF_INPUT_INTEXT = "自文本";
Blockly.Msg.TEXT_INDEXOF_OPERATOR_FIRST = "寻找第一个出现的文本";
Blockly.Msg.TEXT_INDEXOF_OPERATOR_LAST = "寻找最后一个出现的文本";
Blockly.Msg.TEXT_INDEXOF_TAIL = "空白";
Blockly.Msg.TEXT_INDEXOF_TOOLTIP = "返回在第二个字串中的第一/最后一个匹配项的索引值。如果未找到则返回 0。";
Blockly.Msg.TEXT_ISEMPTY_HELPURL = "https://github.com/google/blockly/wiki/Text#checking-for-empty-text";  // untranslated
Blockly.Msg.TEXT_ISEMPTY_TITLE = "%1是空的";
Blockly.Msg.TEXT_ISEMPTY_TOOLTIP = "如果提供的文本为空，则返回真。";
Blockly.Msg.TEXT_JOIN_HELPURL = "https://github.com/google/blockly/wiki/Text#text-creation";  // untranslated
Blockly.Msg.TEXT_JOIN_TITLE_CREATEWITH = "建立字串使用";
Blockly.Msg.TEXT_JOIN_TOOLTIP = "通过串起任意数量的项以建立一段文字。";
Blockly.Msg.TEXT_LENGTH_HELPURL = "https://github.com/google/blockly/wiki/Text#text-modification";  // untranslated
Blockly.Msg.TEXT_LENGTH_TITLE = "%1的长度";
Blockly.Msg.TEXT_LENGTH_TOOLTIP = "返回提供文本的字母数（包括空格）。";
Blockly.Msg.TEXT_PRINT_HELPURL = "https://github.com/google/blockly/wiki/Text#printing-text";  // untranslated
Blockly.Msg.TEXT_PRINT_TITLE = "打印%1";
Blockly.Msg.TEXT_PRINT_TOOLTIP = "打印指定的文字、数字或其他值。";
Blockly.Msg.TEXT_PROMPT_HELPURL = "https://github.com/google/blockly/wiki/Text#getting-input-from-the-user";  // untranslated
Blockly.Msg.TEXT_PROMPT_TOOLTIP_NUMBER = "提示用户输入数字。";
Blockly.Msg.TEXT_PROMPT_TOOLTIP_TEXT = "提示用户输入一些文本。";
Blockly.Msg.TEXT_PROMPT_TYPE_NUMBER = "输入数字并显示提示消息";
Blockly.Msg.TEXT_PROMPT_TYPE_TEXT = "输入数字并显示提示消息";
Blockly.Msg.TEXT_TEXT_HELPURL = "https://zh.wikipedia.org/wiki/字符串";
Blockly.Msg.TEXT_TEXT_TOOLTIP = "一个字母、单词或一行文本。";
Blockly.Msg.TEXT_TRIM_HELPURL = "https://github.com/google/blockly/wiki/Text#trimming-removing-spaces";  // untranslated
Blockly.Msg.TEXT_TRIM_OPERATOR_BOTH = "消除两侧空格";
Blockly.Msg.TEXT_TRIM_OPERATOR_LEFT = "消除左侧空格";
Blockly.Msg.TEXT_TRIM_OPERATOR_RIGHT = "消除右侧空格";
Blockly.Msg.TEXT_TRIM_TOOLTIP = "复制这段文字的同时删除两端多余的空格。";
Blockly.Msg.TODAY = "今天";
Blockly.Msg.VARIABLES_DEFAULT_NAME = "项目";
Blockly.Msg.VARIABLES_GET_CREATE_SET = "创建“设定%1”";
Blockly.Msg.VARIABLES_GET_HELPURL = "https://github.com/google/blockly/wiki/Variables#get";  // untranslated
Blockly.Msg.VARIABLES_GET_TOOLTIP = "返回此变量的值。";
Blockly.Msg.VARIABLES_SET = "赋值 %1 到 %2";
Blockly.Msg.VARIABLES_SET_CREATE_GET = "创建“获得%1”";
Blockly.Msg.VARIABLES_SET_HELPURL = "https://github.com/google/blockly/wiki/Variables#set";  // untranslated
Blockly.Msg.VARIABLES_SET_TOOLTIP = "设置此变量，以使它和输入值相等。";
Blockly.Msg.PROCEDURES_DEFRETURN_TITLE = Blockly.Msg.PROCEDURES_DEFNORETURN_TITLE;
Blockly.Msg.CONTROLS_IF_IF_TITLE_IF = Blockly.Msg.CONTROLS_IF_MSG_IF;
Blockly.Msg.CONTROLS_WHILEUNTIL_INPUT_DO = Blockly.Msg.CONTROLS_REPEAT_INPUT_DO;
Blockly.Msg.CONTROLS_IF_MSG_THEN = Blockly.Msg.CONTROLS_REPEAT_INPUT_DO;
Blockly.Msg.PROCEDURES_DEFRETURN_PROCEDURE = Blockly.Msg.PROCEDURES_DEFNORETURN_PROCEDURE;
Blockly.Msg.CONTROLS_IF_ELSE_TITLE_ELSE = Blockly.Msg.CONTROLS_IF_MSG_ELSE;
Blockly.Msg.PROCEDURES_CALLRETURN_CALL = Blockly.Msg.PROCEDURES_CALLNORETURN_CALL;
Blockly.Msg.LISTS_GET_SUBLIST_INPUT_IN_LIST = Blockly.Msg.LISTS_INLIST;
Blockly.Msg.LISTS_GET_INDEX_INPUT_IN_LIST = Blockly.Msg.LISTS_INLIST;
Blockly.Msg.MATH_CHANGE_TITLE_ITEM = Blockly.Msg.VARIABLES_DEFAULT_NAME;
Blockly.Msg.PROCEDURES_DEFRETURN_DO = Blockly.Msg.PROCEDURES_DEFNORETURN_DO;
Blockly.Msg.CONTROLS_IF_ELSEIF_TITLE_ELSEIF = Blockly.Msg.CONTROLS_IF_MSG_ELSEIF;
Blockly.Msg.LISTS_GET_INDEX_HELPURL = Blockly.Msg.LISTS_INDEX_OF_HELPURL;
Blockly.Msg.CONTROLS_FOREACH_INPUT_DO = Blockly.Msg.CONTROLS_REPEAT_INPUT_DO;
Blockly.Msg.CONTROLS_FOR_INPUT_DO = Blockly.Msg.CONTROLS_REPEAT_INPUT_DO;
Blockly.Msg.LISTS_CREATE_WITH_ITEM_TITLE = Blockly.Msg.VARIABLES_DEFAULT_NAME;
Blockly.Msg.TEXT_APPEND_VARIABLE = Blockly.Msg.VARIABLES_DEFAULT_NAME;
Blockly.Msg.TEXT_CREATE_JOIN_ITEM_TITLE_ITEM = Blockly.Msg.VARIABLES_DEFAULT_NAME;
Blockly.Msg.LISTS_INDEX_OF_INPUT_IN_LIST = Blockly.Msg.LISTS_INLIST;
Blockly.Msg.LISTS_SET_INDEX_INPUT_IN_LIST = Blockly.Msg.LISTS_INLIST;